# - Try to find KMSELEMENTS library

#=============================================================================
# Copyright 2014 Kurento
#
#=============================================================================

set(PACKAGE_VERSION "5.0.4")
set(KMSELEMENTS_VERSION ${PACKAGE_VERSION})

message (STATUS "Looking for KMSELEMENTS: 5.0.4")

include (GenericFind)

generic_find (
  REQUIRED
  LIBNAME KMSCORE
  VERSION ^5.0.0
)

set (REQUIRED_VARS
  KMSELEMENTS_VERSION
  KMSELEMENTS_INCLUDE_DIRS
  KMSELEMENTS_LIBRARY
  KMSELEMENTS_LIBRARIES
)

set(KMSELEMENTS_INCLUDE_DIRS
  ${KMSCORE_INCLUDE_DIRS}
)

if (NOT "MediaProfileSpecType.hpp RecorderEndpoint.hpp DispatcherOneToMany.hpp PlayerEndpoint.hpp PlumberEndpoint.hpp WebRtcEndpoint.hpp Mixer.hpp Composite.hpp RtpEndpoint.hpp HttpGetEndpoint.hpp HttpPostEndpoint.hpp HttpEndpoint.hpp AlphaBlending.hpp Dispatcher.hpp EndOfStream.hpp RecorderEndpointInternal.hpp DispatcherOneToManyInternal.hpp PlayerEndpointInternal.hpp PlumberEndpointInternal.hpp WebRtcEndpointInternal.hpp MixerInternal.hpp CompositeInternal.hpp RtpEndpointInternal.hpp HttpGetEndpointInternal.hpp HttpPostEndpointInternal.hpp HttpEndpointInternal.hpp AlphaBlendingInternal.hpp DispatcherInternal.hpp" STREQUAL " ")
  find_path(KMSELEMENTS_INTERFACE_INCLUDE_DIR
    NAMES
      MediaProfileSpecType.hpp RecorderEndpoint.hpp DispatcherOneToMany.hpp PlayerEndpoint.hpp PlumberEndpoint.hpp WebRtcEndpoint.hpp Mixer.hpp Composite.hpp RtpEndpoint.hpp HttpGetEndpoint.hpp HttpPostEndpoint.hpp HttpEndpoint.hpp AlphaBlending.hpp Dispatcher.hpp EndOfStream.hpp
      RecorderEndpointInternal.hpp DispatcherOneToManyInternal.hpp PlayerEndpointInternal.hpp PlumberEndpointInternal.hpp WebRtcEndpointInternal.hpp MixerInternal.hpp CompositeInternal.hpp RtpEndpointInternal.hpp HttpGetEndpointInternal.hpp HttpPostEndpointInternal.hpp HttpEndpointInternal.hpp AlphaBlendingInternal.hpp DispatcherInternal.hpp
    PATH_SUFFIXES
      obj-x86_64-linux-gnu/src/server/interface/generated-cpp
      kurento/modules/elements
  )

  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${KMSELEMENTS_INTERFACE_INCLUDE_DIR})
  list (APPEND REQUIRED_VARS KMSELEMENTS_INTERFACE_INCLUDE_DIR)
endif ()

if (NOT "RecorderEndpointImplFactory.hpp DispatcherOneToManyImplFactory.hpp PlayerEndpointImplFactory.hpp PlumberEndpointImplFactory.hpp WebRtcEndpointImplFactory.hpp MixerImplFactory.hpp CompositeImplFactory.hpp RtpEndpointImplFactory.hpp HttpGetEndpointImplFactory.hpp HttpPostEndpointImplFactory.hpp HttpEndpointImplFactory.hpp AlphaBlendingImplFactory.hpp DispatcherImplFactory.hpp" STREQUAL "")
  find_path(KMSELEMENTS_IMPLEMENTATION_INTERNAL_INCLUDE_DIR
    NAMES
      RecorderEndpointImplFactory.hpp DispatcherOneToManyImplFactory.hpp PlayerEndpointImplFactory.hpp PlumberEndpointImplFactory.hpp WebRtcEndpointImplFactory.hpp MixerImplFactory.hpp CompositeImplFactory.hpp RtpEndpointImplFactory.hpp HttpGetEndpointImplFactory.hpp HttpPostEndpointImplFactory.hpp HttpEndpointImplFactory.hpp AlphaBlendingImplFactory.hpp DispatcherImplFactory.hpp
    PATH_SUFFIXES
      obj-x86_64-linux-gnu/src/server/implementation/generated-cpp
      kurento/modules/elements
  )

  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${KMSELEMENTS_IMPLEMENTATION_INTERNAL_INCLUDE_DIR})
  list (APPEND REQUIRED_VARS KMSELEMENTS_IMPLEMENTATION_INTERNAL_INCLUDE_DIR)
endif ()

if (NOT "RecorderEndpointImpl.hpp DispatcherOneToManyImpl.hpp PlayerEndpointImpl.hpp PlumberEndpointImpl.hpp WebRtcEndpointImpl.hpp MixerImpl.hpp CompositeImpl.hpp RtpEndpointImpl.hpp HttpGetEndpointImpl.hpp HttpPostEndpointImpl.hpp HttpEndpointImpl.hpp AlphaBlendingImpl.hpp DispatcherImpl.hpp" STREQUAL "")
  find_path(KMSELEMENTS_IMPLEMENTATION_GENERATED_INCLUDE_DIR
    NAMES
      RecorderEndpointImpl.hpp DispatcherOneToManyImpl.hpp PlayerEndpointImpl.hpp PlumberEndpointImpl.hpp WebRtcEndpointImpl.hpp MixerImpl.hpp CompositeImpl.hpp RtpEndpointImpl.hpp HttpGetEndpointImpl.hpp HttpPostEndpointImpl.hpp HttpEndpointImpl.hpp AlphaBlendingImpl.hpp DispatcherImpl.hpp
    PATH_SUFFIXES
      src/server/implementation/objects
      kurento/modules/elements
  )

  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${KMSELEMENTS_IMPLEMENTATION_GENERATED_INCLUDE_DIR})
  list (APPEND REQUIRED_VARS KMSELEMENTS_IMPLEMENTATION_GENERATED_INCLUDE_DIR)
endif()

if (NOT "" STREQUAL "")
  find_path(KMSELEMENTS_IMPLEMENTATION_EXTRA_INCLUDE_DIR
    NAMES
      
    PATH_SUFFIXES
      
      kurento/modules/elements
  )

  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${KMSELEMENTS_IMPLEMENTATION_EXTRA_INCLUDE_DIR})
  list (APPEND REQUIRED_VARS KMSELEMENTS_IMPLEMENTATION_EXTRA_INCLUDE_DIR)
endif ()

if (NOT "" STREQUAL "")
  find_path(KMSELEMENTS_INTERFACE_EXTRA_INCLUDE_DIR
    NAMES
      
    PATH_SUFFIXES
      
      kurento/modules/elements
  )

  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${KMSELEMENTS_INTERFACE_EXTRA_INCLUDE_DIR})
  list (APPEND REQUIRED_VARS KMSELEMENTS_INTERFACE_EXTRA_INCLUDE_DIR)
endif ()

find_library (KMSELEMENTS_LIBRARY
  NAMES
    kmselementsimpl
  PATH_SUFFIXES
    build/src/server
)

set (REQUIRED_LIBS "")
foreach (LIB ${REQUIRED_LIBS})
  string(FIND ${LIB} " " POS)

  if (${POS} GREATER 0)
    string (SUBSTRING ${LIB} 0 ${POS} LIB_NAME)
    string (SUBSTRING ${LIB} ${POS} -1 LIB_VERSION)
    string (STRIP ${LIB_NAME} LIB_NAME)
    string (STRIP ${LIB_VERSION} LIB_VERSION)
    generic_find (LIBNAME ${LIB_NAME} REQUIRED VERSION "${LIB_VERSION}")
  else ()
    string (STRIP ${LIB} LIB_NAME)
    generic_find (LIBNAME ${LIB_NAME} REQUIRED)
  endif ()
  list (APPEND REQUIRED_LIBRARIES ${${LIB_NAME}_LIBRARIES})
  list (APPEND KMSELEMENTS_INCLUDE_DIRS ${${LIB_NAME}_INCLUDE_DIRS})

endforeach()

set(KMSELEMENTS_INCLUDE_DIRS
  ${KMSELEMENTS_INCLUDE_DIRS}
  CACHE INTERNAL "Include directories for KMSELEMENTS library"
)

set (KMSELEMENTS_LIBRARIES
  ${KMSELEMENTS_LIBRARY}
  ${KMSCORE_LIBRARIES}
  ${REQUIRED_LIBRARIES}
  CACHE INTERNAL "Libraries for KMSELEMENTS"
)

include (FindPackageHandleStandardArgs)

find_package_handle_standard_args(KMSELEMENTS
  FOUND_VAR
    KMSELEMENTS_FOUND
  REQUIRED_VARS
    ${REQUIRED_VARS}
  VERSION_VAR
    KMSELEMENTS_VERSION
)

mark_as_advanced(
  KMSELEMENTS_FOUND
  KMSELEMENTS_VERSION
  KMSELEMENTS_INTERFACE_INCLUDE_DIR
  KMSELEMENTS_IMPLEMENTATION_INTERNAL_INCLUDE_DIR
  KMSELEMENTS_IMPLEMENTATION_GENERATED_INCLUDE_DIR
  KMSELEMENTS_IMPLEMENTATION_EXTRA_INCLUDE_DIR
  KMSELEMENTS_INTERFACE_EXTRA_INCLUDE_DIR
  KMSELEMENTS_INCLUDE_DIRS
  KMSELEMENTS_LIBRARY
  KMSELEMENTS_LIBRARIES
)
